*******************************************************************
pens: utilities for comparing paleoclimate reconstruction ensembles
*******************************************************************

`pens` aims to provide a toolbox for comparing paleoclimate reconstruction ensembles.

Documentation
=============

+ Homepage: https://fzhu2e.github.io/pens
+ Installation: https://fzhu2e.github.io/pens/ug-installation.html